# Changelog

## Version v0.0.14 (2024/06/28)

- Add CategorizeNorm
- CategoryNorm now expects a {key: label} dictionary
- Fix issue with users provided levels

## Version v0.0.11 (2024/03/28)

- Fix ticklabels dynamic layout for BoundaryNorm and CategoryNorm

## Version 0.0.10 (2024/03/26)

### Pull Requests Merged

* [PR 15](https://github.com/ghiggi/pycolorbar/pull/15) - Bump actions/checkout from 3 to 4, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 14](https://github.com/ghiggi/pycolorbar/pull/14) - Add automatic changelog generation, by [@sphamba](https://github.com/sphamba)
* [PR 13](https://github.com/ghiggi/pycolorbar/pull/13) - [pre-commit.ci] pre-commit autoupdate, by [@pre-commit-ci[bot]](https://github.com/apps/pre-commit-ci)
* [PR 12](https://github.com/ghiggi/pycolorbar/pull/12) - Fix GitHub release, by [@sphamba](https://github.com/sphamba)
* [PR 11](https://github.com/ghiggi/pycolorbar/pull/11) - Bump softprops/action-gh-release from 1 to 2, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 10](https://github.com/ghiggi/pycolorbar/pull/10) - Bump pre-commit/action from 3.0.0 to 3.0.1, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 9](https://github.com/ghiggi/pycolorbar/pull/9) - Bump actions/checkout from 3 to 4, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 8](https://github.com/ghiggi/pycolorbar/pull/8) - Replace deprecated GitHub release actions, by [@sphamba](https://github.com/sphamba)
* [PR 7](https://github.com/ghiggi/pycolorbar/pull/7) - Bump actions/checkout from 2 to 4, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 6](https://github.com/ghiggi/pycolorbar/pull/6) - Bump codecov/codecov-action from 3 to 4, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 5](https://github.com/ghiggi/pycolorbar/pull/5) - Bump actions/setup-python from 2 to 5, by [@dependabot[bot]](https://github.com/apps/dependabot)
* [PR 2](https://github.com/ghiggi/pycolorbar/pull/2) - Update pre-commit and CI, by [@sphamba](https://github.com/sphamba)
* [PR 1](https://github.com/ghiggi/pycolorbar/pull/1) - [pre-commit.ci] pre-commit autoupdate, by [@pre-commit-ci[bot]](https://github.com/apps/pre-commit-ci)

In this release 14 pull requests were closed.

## Version 0.0.1 (2023-06-10)

First release of pycolorbar
